==> 0.0.10.tar.gz: lib/src/android/android.export.g.dart <==
export 'type_op.g.dart';
export 'constants.g.dart';
export 'platformview/TXCloudVideoView.g.dart';
export 'com/tencent/rtmp/TXLivePlayer.g.dart';
export 'com/tencent/rtmp/ui/TXDashBoard.g.dart';
export 'com/tencent/rtmp/ui/TXCloudVideoView.g.dart';
export 'com/tencent/rtmp/ui/TXLogView.g.dart';
export 'com/tencent/rtmp/ITXLivePlayListener.g.dart';
export 'com/tencent/rtmp/video/TXScreenCapture.g.dart';
export 'com/tencent/rtmp/video/TXScreenCapture/TXScreenCaptureAssistantActivity.g.dart';
export 'com/tencent/rtmp/TXLiveBaseListener.g.dart';
export 'com/tencent/rtmp/TXPlayerAuthBuilder.g.dart';
export 'com/tencent/rtmp/ITXLivePushListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/TXLiteAVTexture.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXLivePlayVideoRenderListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXSnapshotListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXAudioVolumeEvaluationListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXAudioRawDataListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXVideoRawDataListener.g.dart';
export 'com/tencent/rtmp/TXPlayerGlobalSetting.g.dart';
export 'com/tencent/rtmp/TXLiveConstants.g.dart';
export 'com/tencent/rtmp/downloader/ITXVodPreloadListener.g.dart';
export 'com/tencent/rtmp/downloader/TXVodPreloadManager.g.dart';
export 'com/tencent/rtmp/downloader/ITXVodDownloadListener.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadDataSource.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadManager.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadMediaInfo.g.dart';
export 'com/tencent/rtmp/TXLivePlayConfig.g.dart';
export 'com/tencent/rtmp/TXVodPlayConfig.g.dart';
export 'com/tencent/rtmp/TXLiveBase.g.dart';
export 'com/tencent/rtmp/TXBitrateItem.g.dart';
export 'com/tencent/rtmp/ITXVodPlayListener.g.dart';
export 'com/tencent/rtmp/TXLog.g.dart';
export 'com/tencent/rtmp/TXImageSprite.g.dart';
export 'com/tencent/rtmp/TXVodPlayer.g.dart';
export 'com/tencent/rtmp/TXPlayInfoParams.g.dart';
export '../facade/shared.g.dart';

==> 0.0.18.tar.gz: lib/src/android/android.export.g.dart <==
export 'type_op.g.dart';
export 'constants.g.dart';
export 'platformview/TXCloudVideoView.g.dart';
export 'com/tencent/rtmp/TXLivePlayer.g.dart';
export 'com/tencent/rtmp/ui/DashBoard.g.dart';
export 'com/tencent/rtmp/ui/TXCloudVideoView.g.dart';
export 'com/tencent/rtmp/ITXLivePlayListener.g.dart';
export 'com/tencent/rtmp/TXLiveBaseListener.g.dart';
export 'com/tencent/rtmp/TXPlayerAuthBuilder.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/TXLiteAVTexture.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXLivePlayVideoRenderListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXSnapshotListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXAudioVolumeEvaluationListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXAudioRawDataListener.g.dart';
export 'com/tencent/rtmp/TXLivePlayer/ITXVideoRawDataListener.g.dart';
export 'com/tencent/rtmp/TXPlayerGlobalSetting.g.dart';
export 'com/tencent/rtmp/TXLiveConstants.g.dart';
export 'com/tencent/rtmp/downloader/ITXVodPreloadListener.g.dart';
export 'com/tencent/rtmp/downloader/TXVodPreloadManager.g.dart';
export 'com/tencent/rtmp/downloader/ITXVodDownloadListener.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadDataSource.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadManager.g.dart';
export 'com/tencent/rtmp/downloader/TXVodDownloadMediaInfo.g.dart';
export 'com/tencent/rtmp/TXLivePlayConfig.g.dart';
export 'com/tencent/rtmp/TXVodPlayConfig.g.dart';
export 'com/tencent/rtmp/TXLiveBase.g.dart';
export 'com/tencent/rtmp/TXBitrateItem.g.dart';
export 'com/tencent/rtmp/ITXVodPlayListener.g.dart';
export 'com/tencent/rtmp/TXVodConstants.g.dart';
export 'com/tencent/rtmp/TXImageSprite.g.dart';
export 'com/tencent/rtmp/TXVodPlayer.g.dart';
export 'com/tencent/rtmp/TXPlayInfoParams.g.dart';
export 'com/tencent/rtmp/TXPlayerDrmBuilder.g.dart';
export 'package:volume_controller/volume_controller.dart';
export '../facade/shared.g.dart';
